#ifndef inittab_h
#define inittab_h
#ifndef MISC_H
    #include <misc.h>
#endif
#ifndef MODULE_H
    #include <module.h>
#endif

#include <modapi_def.h>
#include <modapi.h>
class MODULE_inittab: public LINUXCONF_MODULE{
    /*~PROTOBEG~ MODULE_inittab */
public:
	MODULE_inittab (void);
	int domenu (MENU_CONTEXT context,
		 const char *key);
	int execmain (int argc, char *argv[], bool);
	void setmenu (DIALOG&dia, MENU_CONTEXT context);
	void usage (SSTRINGS&tb);
    /*~PROTOEND~ MODULE_inittab */
};

#include "inittab.p"

#endif
